@@ -205,9 +205,9 @@ class CfnAssessmentTemplate(
         *,
         assessment_target_arn: builtins.str,
         duration_in_seconds: jsii.Number,
-        rules_package_arns: typing.List[builtins.str],
+        rules_package_arns: typing.Sequence[builtins.str],
         assessment_template_name: typing.Optional[builtins.str] = None,
-        user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]] = None,
+        user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]] = None,
     ) -> None:
         '''Create a new ``AWS::Inspector::AssessmentTemplate``.
 
@@ -356,9 +356,9 @@ class CfnAssessmentTemplateProps:
         *,
         assessment_target_arn: builtins.str,
         duration_in_seconds: jsii.Number,
-        rules_package_arns: typing.List[builtins.str],
+        rules_package_arns: typing.Sequence[builtins.str],
         assessment_template_name: typing.Optional[builtins.str] = None,
-        user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]] = None,
+        user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
@@ -459,7 +459,7 @@ class CfnResourceGroup(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]],
+        resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]],
     ) -> None:
         '''Create a new ``AWS::Inspector::ResourceGroup``.
 
@@ -538,7 +538,7 @@ class CfnResourceGroupProps:
     def __init__(
         self,
         *,
-        resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]],
+        resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]],
     ) -> None:
         '''Properties for defining a ``AWS::Inspector::ResourceGroup``.
 
